import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import javax.swing.JPanel;

/**
 * A JPanel of the given color that displays a square of the given characteristics.
 *
 * @author David Mutchler. Created Mar 19, 2009.
 */
public class SquarePanel extends JPanel {
	private int squareWidth;
	private Color squareColor;
	
	/**
	 * Stores the characteristics of the given square
	 * and constructs a JPanel with the given color
	 * and a size five that of the given square.
	 *
	 * @param squareWidth width/height of the square to display
	 * @param squareColor color of the square to display
	 * @param panelColor color of the panel
	 */
	public SquarePanel(int squareWidth, Color squareColor, Color panelColor) {
		this.squareWidth = squareWidth;
		this.squareColor = squareColor;
		
		int panelWidth = Math.min(this.squareWidth * 5, SimpleFrame.FRAME_SIZE.width / 2);
		int panelHeight = Math.min(this.squareWidth * 5, SimpleFrame.FRAME_SIZE.height / 2);
		this.setPreferredSize(new Dimension(panelWidth, panelHeight));
		
		this.setBackground(panelColor);
	}
	
	/**
	 * Draws the square for this panel.
	 * 
	 * @param graphics Graphics object onto which to draw
	 */
	@Override
	public void paintComponent(Graphics graphics) {
		super.paintComponent(graphics);
		
		graphics.setColor(this.squareColor);
		graphics.fillRect(50, 50, this.squareWidth, this.squareWidth);
		
		// TODO: Add your own drawing commands here, including:
		//   - another filled rectangle, somewhere else on the panel
		//   - a circle
		//   - something in a different color
		//   - something else
	}
}
